@@ -1,12 +1,10 @@
-from gi.repository import Gio, GLib
+from gi.repository import Adw, Gio, GLib
 
+from enum import StrEnum
 import logging
 from typing import Optional
 
-# Change to Python interval version from Python v3.11
-from enum import StrEnum
-
-from iotas import const
+import iotas.const as const
 
 settings = Gio.Settings.new(const.APP_ID)
 
@@ -260,8 +258,8 @@ def set_index_category_style(value: str) -> None:
     settings.set_string(INDEX_CATEGORY_STYLE, value)
 
 
-def get_persist_sidebar() -> bool:
-    """Get whether to persist the index sidebar (in large windows).
+def get_pin_sidebar() -> bool:
+    """Get whether to pin the index sidebar (in large windows).
 
     :return: Whether to hide
     :rtype: bool
@@ -269,8 +267,8 @@ def get_persist_sidebar() -> bool:
     return settings.get_value(PERSIST_SIDEBAR)
 
 
-def set_persist_sidebar(value: bool) -> None:
-    """Set whether to persist the index sidebar (in large windows).
+def set_pin_sidebar(value: bool) -> None:
+    """Set whether to pin the index sidebar (in large windows).
 
     :param bool value: New value
     """
@@ -302,12 +300,39 @@ def get_editor_formatting_bar_visibility() -> Optional[HeaderBarVisibility]:
     """
     setting_value = settings.get_string(EDITOR_FORMATTING_BAR_VISIBILTY)
     try:
-        service = HeaderBarVisibility(setting_value)
+        obj = HeaderBarVisibility(setting_value)
     except ValueError as e:
         logging.warning(f"Couldn't parse formatting bar visibility from '{setting_value}': {e}")
         return None
     else:
-        return service
+        return obj
+
+
+def get_editor_formatting_bar_visible_for_window_state() -> bool:
+    """Get whether the formatting bar is configured visible for the window maximised state."
+
+    :return: Whether visible
+    :rtype: bool
+    """
+    setting_value = settings.get_string(EDITOR_FORMATTING_BAR_VISIBILTY)
+    try:
+        obj = HeaderBarVisibility(setting_value)
+    except ValueError as e:
+        logging.warning(f"Couldn't parse formatting bar visibility from '{setting_value}': {e}")
+        return False
+    else:
+        visible = False
+        if get_markdown_detect_syntax():
+            if obj == HeaderBarVisibility.ALWAYS_VISIBLE:
+                visible = True
+            elif obj == HeaderBarVisibility.AUTO_HIDE_FULLSCREEN_ONLY:
+                app = Gio.Application.get_default()
+                if not app:
+                    logging.error("Couldn't get app?")
+                    return False
+                window = app.get_active_window()
+                visible = not window.is_fullscreen()
+        return visible
 
 
 def set_editor_formatting_bar_visibility(value: HeaderBarVisibility) -> None:
@@ -326,12 +351,38 @@ def get_editor_header_bar_visibility() -> Optional[HeaderBarVisibility]:
     """
     setting_value = settings.get_string(EDITOR_HEADER_BAR_VISIBILTY)
     try:
-        service = HeaderBarVisibility(setting_value)
+        obj = HeaderBarVisibility(setting_value)
     except ValueError as e:
         logging.warning(f"Couldn't parse header bar visibility from '{setting_value}': {e}")
         return None
     else:
-        return service
+        return obj
+
+
+def get_editor_header_bar_visible_for_window_state() -> bool:
+    """Get whether the header bar is configured visible for the window maximised state."
+
+    :return: Whether visible
+    :rtype: bool
+    """
+    setting_value = settings.get_string(EDITOR_HEADER_BAR_VISIBILTY)
+    try:
+        obj = HeaderBarVisibility(setting_value)
+    except ValueError as e:
+        logging.warning(f"Couldn't parse header bar visibility from '{setting_value}': {e}")
+        return False
+    else:
+        visible = False
+        if obj == HeaderBarVisibility.ALWAYS_VISIBLE:
+            visible = True
+        elif obj == HeaderBarVisibility.AUTO_HIDE_FULLSCREEN_ONLY:
+            app = Gio.Application.get_default()
+            if not app:
+                logging.error("Couldn't get app?")
+                return False
+            window = app.get_active_window()
+            visible = not window.is_fullscreen()
+        return visible
 
 
 def set_editor_header_bar_visibility(value: HeaderBarVisibility) -> None:
@@ -645,6 +696,28 @@ def set_network_timeout(value: float) -> None:
     settings.set_double(NETWORK_TIMEOUT, value)
 
 
+# Piped through the configuration manager for now as a result of the HTML generator using it
+# directly as configuration.
+def get_toolbar_underlay_padding_height() -> int:
+    """Fetch the height of padding to account for overlay header bars.
+
+    :return: Height in pixels
+    :rtype: int
+    """
+    return const.HEADER_BAR_HEIGHT
+
+
+# Piped through the configuration manager for now as a result of the HTML generator using it
+# directly as configuration.
+def get_high_contrast() -> bool:
+    """Get whether high contrast output should be used for screen rendering.
+
+    :return: Whether visible
+    :rtype: bool
+    """
+    return Adw.StyleManager.get_default().get_high_contrast()
+
+
 # TODO remove ~early 2025 #####################################################
 
 # Retaining to migrate
